@@ -11,7 +11,7 @@ from flashpolicies import policies
 def serve(request, policy):
     """
     Given a ``flashpolicies.policies.Policy`` instance, serialize it
-    to XML and serve it. Internall, this is used by all other views as
+    to XML and serve it. Internally, this is used by all other views as
     the mechanism which actually serves the policy file.
 
     **Required arguments:**
@@ -24,7 +24,7 @@ def serve(request, policy):
     None.
 
     """
-    return HttpResponse(policy.xml_dom.toprettyxml(encoding='utf-8'),
+    return HttpResponse(str(policy),
                         content_type='text/x-cross-domain-policy; charset=utf-8')
 
 
